@@ -319,10 +319,10 @@ void MainProg::eventhandle(NEvent* ev)	//обработчик событий К
 		if (!destroybyid(typeid(AddProjectForm).name()))
 		{
 		    TuiEvent* ev1 = (TuiEvent*)ev;
-		    Srv* srv = gsrvlist->getcursrv();
+            //Srv* srv = gsrvlist->getcursrv();
 		    if (ev1->srv != NULL)
 		    {
-			AddProjectForm* addform = new AddProjectForm(30,65,ev1->srv,ev1->sdata1.c_str(),ev1->bdata1);
+			AddProjectForm* addform = new AddProjectForm(30,65,ev1->srv,ev1->sdata1.c_str(),ev1->bdata1, ev1->bdata2);
 			insert(addform);
 			addform->move(getmaxy(stdscr)/2-addform->getheight()/2,getmaxx(stdscr)/2-addform->getwidth()/2); //центрируем
 			uistate = uistate | stUIMODALFORM;
@@ -338,7 +338,7 @@ void MainProg::eventhandle(NEvent* ev)	//обработчик событий К
 		if (!destroybyid(typeid(AddAccMgrForm).name()))
 		{
 		    TuiEvent* ev1 = (TuiEvent*)ev;
-		    Srv* srv = gsrvlist->getcursrv();
+            //Srv* srv = gsrvlist->getcursrv();
 		    if (ev1->srv != NULL)
 		    {
 			AddAccMgrForm* addmgrform = new AddAccMgrForm(30,65,ev1->srv,ev1->sdata1.c_str());
