@@ -19,7 +19,11 @@
 #define NVIEW_H
 
 #include <typeinfo>
-#include <panel.h>
+#if HAVE_LIBNCURSESW == 1 && NCURSESW_HAVE_SUBDIR == 1
+    #include <ncursesw/panel.h>
+#else
+    #include <panel.h>
+#endif
 #include "nrect.h"
 #include "nevent.h"
 
